@@ -1,10 +1,10 @@
-require 'gphys_const_v1.1'
+require './gphys_const_v1.1'
 require "numru/ggraph"
 include NumRu
 
-dir = '..'
-dir = '../util_s2p-2011-12-15/out'
-dir = '../util_s2p-2012-09-12/out'
+#dir = '..'
+#dir = '../util_s2p-2011-12-15/out'
+#dir = '../util_s2p-2012-09-12/out'
 dir = '../util_timemean-2012-11-02/out'
 
 daysOfYear = 0
@@ -16,7 +16,7 @@ p 'DEBUG: days in a year: ' + daysOfYear.to_s
 figdir = 'figs'
 #Dir::mkdir( figdir )
 
-vnames = ['Temp', 'U', 'MSF', 'ANGMOM']
+vnames = ['Temp', 'U', 'V', 'OMG', 'MSF', 'ANGMOM','epflx_div']
 
 iyrs = 3
 iyre = 3
